CustomShapeProgressIndicator class

Inheritance

Constructors

CustomShapeProgressIndicator({double progressLineThickness = 2, Color? progressLineColor, Color? backgroundColor, double progress = 0, Widget? child, double borderRadius = 10, double? height, double? width, int infinityLoadingDelay = 3, double? backgroundLineThickness, Key? key})
const

Properties

backgroundColor Color?
The color of background line
final
backgroundLineThickness double?
The thickness of background shape line
final
borderRadius double
Border radius of the shape
final
child Widget?
child widget
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Height and width of the app.
final
infinityLoadingDelay int
Infinity loading animation delay
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
progress double
The progress of indicator
final
progressLineColor Color?
The color of animating line
final
progressLineThickness double
The thickness of animating progress line
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Height and width of the app.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomShapeProgressIndicator>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited